EXPORTS
	?Close@RSsmStateManager@@QAEXXZ @ 1 NONAME ; void RSsmStateManager::Close(void)
	?Close@RSsmStateManagerTestClient@@QAEXXZ @ 2 NONAME ; void RSsmStateManagerTestClient::Close(void)
	?Connect@RSsmStateManager@@QAEHH@Z @ 3 NONAME ; int RSsmStateManager::Connect(int)
	?Connect@RSsmStateManager@@QAEHXZ @ 4 NONAME ; int RSsmStateManager::Connect(void)
	?Connect@RSsmStateManagerTestClient@@QAEHABVTDesC16@@ABVTVersion@@@Z @ 5 NONAME ; int RSsmStateManagerTestClient::Connect(class TDesC16 const &, class TVersion const &)
	?Connect@RSsmStateManagerTestClient@@QAEHXZ @ 6 NONAME ; int RSsmStateManagerTestClient::Connect(void)
	?HeapMark@RSsmStateManagerTestClient@@QAEHXZ @ 7 NONAME ; int RSsmStateManagerTestClient::HeapMark(void)
	?HeapMarkEnd@RSsmStateManagerTestClient@@QAEHXZ @ 8 NONAME ; int RSsmStateManagerTestClient::HeapMarkEnd(void)
	?RegisterSwpMapping@RSsmStateManager@@QAEHIABVTDesC16@@@Z @ 9 NONAME ; int RSsmStateManager::RegisterSwpMapping(unsigned int, class TDesC16 const &)
	?RequestStateTransition@RSsmStateManager@@QAEHVTSsmStateTransition@@@Z @ 10 NONAME ; int RSsmStateManager::RequestStateTransition(class TSsmStateTransition)
	?RequestStateTransition@RSsmStateManager@@QAEXVTSsmStateTransition@@AAVTRequestStatus@@@Z @ 11 NONAME ; void RSsmStateManager::RequestStateTransition(class TSsmStateTransition, class TRequestStatus &)
	?RequestStateTransitionCancel@RSsmStateManager@@QAEXXZ @ 12 NONAME ; void RSsmStateManager::RequestStateTransitionCancel(void)
	?RequestSwpChange@RSsmStateManager@@QAEHVTSsmSwp@@@Z @ 13 NONAME ; int RSsmStateManager::RequestSwpChange(class TSsmSwp)
	?RequestSwpChange@RSsmStateManager@@QAEXVTSsmSwp@@AAVTRequestStatus@@@Z @ 14 NONAME ; void RSsmStateManager::RequestSwpChange(class TSsmSwp, class TRequestStatus &)
	?RequestSwpChangeCancel@RSsmStateManager@@QAEXXZ @ 15 NONAME ; void RSsmStateManager::RequestSwpChangeCancel(void)
	?RequestDeRegisterSwpMappingL@RSsmStateManagerTestClient@@QAEHIABVTDesC16@@@Z @ 16 NONAME ; int RSsmStateManagerTestClient::RequestDeRegisterSwpMappingL(unsigned int, class TDesC16 const &)
	?HeapMarkEnd@RSsmStateManagerTestClient@@QAEHH@Z @ 17 NONAME ; int RSsmStateManagerTestClient::HeapMarkEnd(int)


